package App::XTermUtils;

our $DATE = '2021-05-26'; # DATE
our $VERSION = '0.007'; # VERSION

1;
# ABSTRACT: Utilities related to XTerm

__END__

=pod

=encoding UTF-8

=head1 NAME

App::XTermUtils - Utilities related to XTerm

=head1 VERSION

This document describes version 0.007 of App::XTermUtils (from Perl distribution App-XTermUtils), released on 2021-05-26.

=head1 DESCRIPTION

This distribution provides the following command-line utilities:

=over

=item * L<get-term-bgcolor>

=item * L<get-term-fgcolor>

=item * L<set-term-bgcolor>

=item * L<set-term-fgcolor>

=item * L<term-bgcolor-is-dark>

=item * L<term-bgcolor-is-light>

=item * L<term-fgcolor-is-dark>

=item * L<term-fgcolor-is-light>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-XTermUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-XTermUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-XTermUtils/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::TermAttrUtils>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2019, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
